# Table of Contents

- [inventory](<./inventory.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Inventory](<./Inventory.md>)
  - [Overview](<./Inventory/Overview.md>)
  - [Searching and Filtering for Fact Sheets](<./Inventory/Searching-and-Filtering-for-Fact-Sheets.md>)
  - [Creating a New Fact Sheet](<./Inventory/Creating-a-New-Fact-Sheet.md>)
  - [Importing and Exporting Fact Sheets](<./Inventory/Importing-and-Exporting-Fact-Sheets.md>)
  - [List View and Table View](<./Inventory/List-View-and-Table-View.md>)
  - [Data Quality Insight Cards](<./Inventory/Data-Quality-Insight-Cards.md>)
  - [Detailed Guides](<./Inventory/Detailed-Guides.md>)
